@@ -260,7 +260,6 @@ class CommandV(Extensible):
         self.build_done_trigger()
         return res
 
-    @utils.traceback_docker_error
     @events
     def create(self):
         """Creates an Odoo dockerized instance with the provided configuration.
@@ -360,7 +359,6 @@ class CommandV(Extensible):
                 " ('user_root', 'user_admin');")
         return 2 if len(admin_users) > 1 else 1
 
-    @utils.traceback_docker_error
     def post_process(self):
         """Command in charge of performing the steps required after deploying an instance
         like generating the cloc report.
@@ -434,7 +432,6 @@ class CommandV(Extensible):
         }
         return res
 
-    @utils.traceback_docker_error
     @events
     def restore(self):
         """Restores a backup from a file or folder. If a folder is provided, searches the best
@@ -504,8 +501,6 @@ class CommandV(Extensible):
         if res.get('error', False):
             self.send_message_error(res)
             return res
-        if self.__config.instance_config.get('instance_type') == 'updates':
-            self.get_db_data(database_name, 'pre-update')
         self.__instance_manager.start_instance()
         logger.debug('restore_res: %s', str(restore_res))
         if restore_from:
@@ -574,6 +569,7 @@ class CommandV(Extensible):
         prefix = '{prefix}_deactivated'.format(prefix=self.__config.prefix)
         db_name = utils.generate_dbname({}, candidate[1], prefix)
         db_config.update({'db_name': db_name})
+        self.__config.postgres.update({"deactivated_db_name": db_name})
         postgres = postgresv.PostgresShell(utils.odoo2postgres(db_config))
         logger.info('Restoring backup to be deactivated')
         postgres.drop(db_name)
@@ -611,7 +607,7 @@ class CommandV(Extensible):
         backup = utils.compress_files(
             backup_name, files2backup, dest_folder=self.__config.store_path,
             cformat=self.__config.cformat)
-        postgres.drop(db_name)
+        postgres.drop(db_name, True)
         if self.__config.upload:
             utils.upload_file(backup, self.__config.upload)
             logger.info('File uploded to %s', self.__config.upload)
@@ -706,7 +702,6 @@ class CommandV(Extensible):
         self.sender.send_message('Data compared', body=res)
         return res
 
-    @utils.traceback_docker_error
     @events
     def updatedb(self, db_name=False):
         """Updates an instance (branches and database) and returns the json with a summary of the
@@ -720,6 +715,8 @@ class CommandV(Extensible):
         self.__config.check_config('updatedb')
         res = {'command': 'updatedb', 'must_parse': True}
         db_name = db_name or self.__config.instance_config.get('config').get('db_name')
+        if self.__config.instance_config.get('instance_type') == 'updates':
+            self.get_db_data(db_name, 'pre-update')
         self.sender.send_message('Updating database "{}".'.format(db_name))
         try:
             self.__instance_manager.stop_instance()
