@@ -192,7 +192,7 @@ class DockerV:
             inspected = self.inspect()
         except errors.NoSuchContainer as error:
             logger.debug(get_error_message(error))
-            return None
+            return {}
 
         env_vars = inspected.get('Config').get('Env')
         res = container.parse_env_vars(env_vars)
@@ -803,10 +803,14 @@ class DockerV:
         image = image or self.config.get('image_name')
         self.pull(image)
         volumes = volumes or self.config.get('volumes')
+        env_vars = self.docker_env
+        env_vars.update(self.config.get('env_vars'))
+        container_env = {key.upper(): value for key, value in env_vars.items()}
         volume_binds = volumes if not working_folder else container.generate_binds(
             volumes, working_folder)
         logger.debug('Executing command: %s', command)
-        cont = self.cli2.containers.run(image, command, volumes=volume_binds, detach=True)
+        cont = self.cli2.containers.run(
+            image, command, volumes=volume_binds, detach=True, environment=container_env)
         while cont.status != 'exited':
             logger.debug(
                 'Waiting for the command to finish, current state: %s', cont.status)
