@@ -188,7 +188,7 @@ class PostgresShell:
             logger.error(("Failed to end the connections to the database %s"),
                          utils.get_error_message(error))
 
-    def dump(self, database, destiny_file, jobs=False):
+    def dump(self, database, destiny_file, jobs=False, exclude=False):
         """Dumps database using pg_dump in sql format.
 
         :param database: database to be dumped.
@@ -207,6 +207,9 @@ class PostgresShell:
         if jobs:
             self.__config.update({'num': jobs})
             dump_cmd = 'pg_dump -j {num} -F d {dbname} -f {0} -x'
+        if exclude:
+            for table in exclude.split(","):
+                dump_cmd += " --exclude-table=%s " % (table)
         dump_cmd = self.__format_cmd(dump_cmd, self.__config)
         dump_cmd = dump_cmd.format(destiny_file, **self.__config)
         logger.debug('Dump command: %s', dump_cmd)
