@@ -133,7 +133,8 @@ class TestContainer(EventListenerBase):
             logger.error('The container %s is not runnig', cid)
             return False
         # Check if odoo instance is running
-        res = obj.instance_manager.exec_cmd('supervisorctl status odoo')
+        res = obj.instance_manager.exec_cmd('supervisorctl status ' +
+                                            obj.instance_manager.supervisor_app)
         if u'RUNNING' not in res:
             logger.error('Odoo instance is not running in container %s', cid)
         else:
