@@ -8,7 +8,7 @@ import zipfile
 _logger = logging.getLogger(__name__)
 
 
-class DatabaseHelper(object):
+class DatabaseHelper:
 
     def __init__(self, db_config):
         self.db_config = db_config
@@ -85,7 +85,7 @@ class RestoreBackup(DatabaseHelper):
         if not dump:
             return (False, 'Could not find any dump in the folder {dest}'.format(dest=dest_dir))
         if not os.path.isdir(dump) and kwargs.get("jobs"):
-            _logger.warn('the backup was not created with parallel jobs')
+            _logger.warning('the backup was not created with parallel jobs')
         elif os.path.isdir(dump):
             jobs = kwargs.get("jobs") or 5
         self._restore_backup(dump, db_name, db_owner, db_owner_password, jobs=jobs)
@@ -94,7 +94,7 @@ class RestoreBackup(DatabaseHelper):
     def _check_backup_folder(self, backup_src, customer_id):
         valid_backups = ['dump.sql', 'database_dump.sql', 'database_dump.b64', "database_dump"]
         if not backup_src or not os.path.exists(backup_src):
-            _logger.warn('Path %s does not exists', backup_src and backup_src or '')
+            _logger.warning('Path %s does not exists', backup_src and backup_src or '')
             res = (False, 'No backup path supplied or does not exits')
         elif os.path.isdir(backup_src):
             if any([bkp for bkp in valid_backups if bkp in os.listdir(backup_src)]):
