@@ -47,12 +47,10 @@ class SenderMessage:
         if body:
             message_body.update(body)
         if msg:
-            log = logger.info if log_type == 'INFO' else logger.error
-            log(msg)
-            message_body.update({'log': '{time} {type} {module}: {msg}'.format(
-                time=datetime.utcnow().isoformat(' '), type=log_type, module=self.__config.command,
-                msg=msg)
-            })
+            getattr(logger, log_type.lower())(msg)
+            values = {'time': datetime.utcnow().isoformat(' '), 'type': log_type, 'msg': msg,
+                      'action': self.__config.action_name}
+            message_body.update({'log': '%(time)s %(type)s deployv.%(action)s: %(msg)s' % values})
         message.set_message_body(message_body, message_type='result')
         if not message.receiver_node_id:
             logger.debug('Failed to send the message: The receiver is required')
