@@ -166,7 +166,6 @@ class InstanceV(DockerV):
                     info.get('name'), info.get('ports'))
         return info
 
-    @utils.traceback_docker_error
     def check_supervisor(self):
         retry = 0
         supervisor_process = self.exec_cmd('pgrep supervisord')
@@ -251,7 +250,7 @@ class InstanceV(DockerV):
         retry = 0
         while retry <= 3:
             try:
-                res = self.exec_cmd('supervisorctl status odoo')
+                res = self.exec_cmd('supervisorctl status ' + self.supervisor_app)
             except errors.NotRunning:
                 retry += 1
                 logger.debug('Container not running, retry %s', retry)
@@ -303,6 +302,20 @@ class InstanceV(DockerV):
     def odoo_binary(self):
         return ODOO_BINARY[self.config_variables.get('version')]
 
+    @property
+    def supervisor_group(self):
+        ct = self.config_variables.get('container_type')
+        if ct == 'MULTIODOO':
+            return 'multiodoo:*'
+        return 'odoo'
+
+    @property
+    def supervisor_app(self):
+        ct = self.config_variables.get('container_type')
+        if ct == 'MULTIODOO':
+            return 'multiodoo:odoo'
+        return 'odoo'
+
     def start_instance(self):
         """ Start an instance inside a docker container using supervisord
 
@@ -310,7 +323,7 @@ class InstanceV(DockerV):
         """
         res = 'RUNNING'
         if not self.is_running:
-            res = self.exec_cmd('supervisorctl start odoo')
+            res = self.exec_cmd('supervisorctl start ' + self.supervisor_group)
             logger.debug('start_instance: %s', res.strip())
         return res
 
@@ -321,7 +334,7 @@ class InstanceV(DockerV):
         """
         res = 'STOPPED'
         if self.is_running:
-            res = self.exec_cmd('supervisorctl stop odoo')
+            res = self.exec_cmd('supervisorctl stop ' + self.supervisor_group)
             logger.info('stop_instance: %s', res.strip())
         return res
 
@@ -653,7 +666,7 @@ class InstanceV(DockerV):
         if not self.__full_config.container_config.get('postgres_container'):
             return {}
         destination = '/var/log/pg_log'
-        if self.config.get('keep_db'):
+        if self.config.get('keep_db') or self.__full_config.reloading_config:
             info = self.inspect(self.config.get('postgres_container_name'))
             db_host = info.get('NetworkSettings').get('IPAddress')
             self.config.update({'pg_log_postgres': self.get_specify_volumen(info, destination)})
@@ -1409,7 +1422,7 @@ class InstanceV(DockerV):
                 res.update({'error': ('Failed to restart the instance: Supervisor'
                                       ' process could not start')})
                 return res
-            self.exec_cmd('supervisorctl stop odoo')
+            self.exec_cmd('supervisorctl stop ' + self.supervisor_group)
             # Check if odoo was successfully stopped
             while retries <= 3:
                 python_process = self.exec_cmd('pgrep python -a').split('\n')
@@ -1424,9 +1437,9 @@ class InstanceV(DockerV):
                 res.update({
                     'error': 'Failed to restart the instance, could not stop odoo'})
                 return res
-            self.exec_cmd('supervisorctl start odoo')
+            self.exec_cmd('supervisorctl start ' + self.supervisor_group)
             if not self.is_running:
-                state = self.exec_cmd('supervisorctl status odoo')
+                state = self.exec_cmd('supervisorctl status ' + self.supervisor_app)
                 res.update({
                     'error': ('Failed to restart the instance, could not'
                               ' start odoo: {state}').format(state=state.strip())})
